@@ -17,6 +17,7 @@ import re
 from html import unescape
 
 import yaml
+from yarl import URL
 from .utils.network_httpx import get_session, request
 from .exceptions.NetworkException import NetworkException, ApiException
 from bs4 import BeautifulSoup, element
@@ -71,8 +72,46 @@ class ArticleType(Enum):
     NOTE = 2
     SPECIAL_ARTICLE = 3
 
+
+class ArticleRankingType(Enum):
+    """
+    专栏排行榜类型枚举。
+
+    + MONTH: 月榜
+    + WEEK: 周榜
+    + DAY_BEFORE_YESTERDAY: 前日榜
+    + YESTERDAY: 昨日榜
+    """
+    MONTH = 1
+    WEEK = 2
+    DAY_BEFORE_YESTERDAY = 4
+    YESTERDAY = 3
+
+
 ArticleT = TypeVar('ArticleT', bound="Article")
 
+
+async def get_article_rank(rank_type: ArticleRankingType = ArticleRankingType.YESTERDAY):
+    """
+    获取专栏排行榜
+
+    Args:
+        rank_type (ArticleRankingType): 排行榜类别. Defaults to ArticleRankingType.YESTERDAY.
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    api = API["info"]["rank"]
+    params = {
+        "cid": rank_type.value
+    }
+    return await request(
+        "GET",
+        api["url"],
+        params=params
+    )
+
+
 class ArticleList:
     """
     文集类
@@ -128,7 +167,6 @@ class Article:
         self.__meta = None
         self.__cvid = cvid
         self.__has_parsed: bool = False
-
         api = API["info"]["view"]
         params = {"id": self.__cvid}
         resp = httpx.request(
@@ -136,7 +174,9 @@ class Article:
         ).json()
 
         # 设置专栏类别
-        if resp["data"]["type"] == 0:
+        if resp["code"] != 0:
+            self.__type = ArticleType.ARTICLE
+        elif resp["data"]["type"] == 0:
             self.__type = ArticleType.ARTICLE
         elif resp["data"]["type"] == 2:
             self.__type = ArticleType.NOTE
@@ -318,8 +358,9 @@ class Article:
 
                         if "img-box" in className:
                             img_el: BeautifulSoup = e.find("img") # type: ignore
-
-                            if "class" in img_el.attrs:
+                            if img_el == None:
+                                pass
+                            elif "class" in img_el.attrs:
                                 className = img_el.attrs["class"]
 
                                 if "cut-off" in className:
@@ -391,8 +432,9 @@ class Article:
 
                                 figcaption_el: BeautifulSoup = e.find("figcaption") # type: ignore
 
-                                if figcaption_el.contents:
-                                    node.alt = figcaption_el.contents[0] # type: ignore
+                                if figcaption_el:
+                                    if figcaption_el.contents:
+                                        node.alt = figcaption_el.contents[0] # type: ignore
 
                         elif "code-box" in className:
                             # 代码块
@@ -456,9 +498,15 @@ class Article:
                         node.text = e.contents[0] # type: ignore
 
                 elif e.name == "img":
-                    className = e.attrs["class"]
+                    className = e.attrs.get("class")
 
-                    if "latex" in className:
+                    if not className:
+                        # 图片
+                        node = ImageNode()
+                        node.url = e.attrs.get("data-src")
+                        node_list.append(node)
+
+                    elif "latex" in className:
                         # 公式
                         node = LatexNode()
                         node_list.append(node)
@@ -841,10 +889,14 @@ class ImageNode(Node):
         self.alt = ""
 
     def markdown(self):
+        if URL(self.url).scheme == "":
+            self.url = "https:" + self.url
         alt = self.alt.replace("[", "\\[")
         return f"![{alt}]({self.url})\n\n"
 
     def json(self):
+        if URL(self.url).scheme == "":
+            self.url = "https:" + self.url
         return {"type": "ImageNode", "url": self.url, "alt": self.alt}
 
 
