@@ -7,7 +7,8 @@ bilibili_api.audio
 from .utils.utils import get_api
 from .utils.Credential import Credential
 from .utils.network_httpx import request
-from typing import Union
+from typing import Union, Optional
+from enum import Enum
 
 API = get_api("audio")
 
