@@ -87,33 +87,38 @@ async def _get_text_data(text: str) -> dict:
     return data
 
 
-async def upload_image(image: Picture, credential: Credential) -> dict:
+async def upload_image(image: Picture, credential: Credential) -> Picture:
     """
     上传动态图片
 
     Args:
-        image        (Picture)   : 图片流
+        image        (Picture)   : 图片流. 有格式要求.
         credential   (Credential): 凭据
 
     Returns:
-        dict: 调用 API 返回的结果
+        Picture: 图片类
     """
     credential.raise_for_no_sessdata()
     credential.raise_for_no_bili_jct()
 
     api = API["send"]["upload_img"]
-    data = {"biz": "draw", "category": "daily"}
-
     raw = image.content
 
-    return await request(
+    data = {"biz": "new_dyn", "category": "daily"}
+
+
+    return_info = await request(
         "POST",
         url=api["url"],
         data=data,
-        files={"file_up": raw},
+        files={
+            "file_up": raw
+        },
         credential=credential,
     )
 
+    return return_info
+
 
 async def _get_draw_data(
     text: str, images: List[Picture], credential: Credential
@@ -130,15 +135,15 @@ async def _get_draw_data(
         *[upload_image(stream, credential) for stream in images]
     )
 
-    def transformPicInfo(image):
+    def transformPicInfo(image: Picture):
         """
         转换图片信息
 
         Args:
-            image ([type]): [description]
+            image (Picture): 图片类
 
         Returns:
-            [type]: [description]
+            dict: 图片信息
         """
         return {
             "img_src": image["image_url"],
@@ -460,3 +465,21 @@ async def get_live_users(size: int = 10, credential: Union[Credential, None] = N
         "size": size
     }
     return await request("GET", api["url"], params = params, credential = credential)
+
+
+async def get_dynamic_page_info(credential: Credential):
+    """
+    获取动态页信息
+
+    Args:
+        credential (Credential): 凭据类.
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    api = API["info"]["dynamic_page_info"]
+    return await request(
+        "GET",
+        api["url"],
+        credential = credential
+    )
