@@ -3,13 +3,14 @@ bilibili_api.live
 
 直播相关
 """
+import base64
 import time
 from enum import Enum
 import logging
 import json
 import struct
 import asyncio
-from typing import List
+from typing import Any, List, Union
 import aiohttp
 import brotli
 
@@ -99,9 +100,13 @@ class LiveCodec(Enum):
 class LiveRoom:
     """
     直播类，获取各种直播间的操作均在里边。
+
+    AttributesL
+        credential      (Credential): 凭据类
+        room_display_id (int)       : 房间展示 id
     """
 
-    def __init__(self, room_display_id: int, credential: Credential = None):
+    def __init__(self, room_display_id: int, credential: Union[Credential, None] = None):
         """
         Args:
             room_display_id (int)                 : 房间展示 ID（即 URL 中的 ID）
@@ -116,12 +121,15 @@ class LiveRoom:
 
         self.__ruid = None
 
-    async def start(self, area_id):
+    async def start(self, area_id: int) -> dict:
         """
         开始直播
 
+        Args:
+            area_id (int): 直播分区id（子分区id）。可使用 live_area 模块查询。
+
         Returns:
-            API 调用返回结果
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["start"]
         params = {
@@ -134,12 +142,12 @@ class LiveRoom:
         )
         return resp
 
-    async def stop(self):
+    async def stop(self) -> dict:
         """
         关闭直播
 
         Returns:
-            API 调用返回结果
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["stop"]
         params = {
@@ -150,12 +158,12 @@ class LiveRoom:
         )
         return resp
 
-    async def get_room_play_info(self):
+    async def get_room_play_info(self) -> dict:
         """
         获取房间信息（真实房间号，封禁情况等）
 
         Returns:
-            API 调用返回结果
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["room_play_info"]
         params = {
@@ -169,24 +177,27 @@ class LiveRoom:
         self.__ruid = resp["uid"]
         return resp
 
-    async def get_room_id(self):
+    async def get_room_id(self) -> int:
         return (await self.get_room_play_info())["room_id"]
 
-    async def __get_ruid(self):
+    async def __get_ruid(self) -> int:
         """
         获取真实房间 ID，若有缓存则使用缓存
         """
         if self.__ruid is None:
             await self.get_room_play_info()
 
-        return self.__ruid
+        return self.__ruid # type: ignore
 
-    async def get_ruid(self):
+    async def get_ruid(self) -> int:
         return await self.__get_ruid()
 
-    async def get_chat_conf(self):
+    async def get_chat_conf(self) -> dict:
         """
         获取聊天弹幕服务器配置信息(websocket)
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["chat_conf"]
         params = {"room_id": self.room_display_id}
@@ -194,9 +205,12 @@ class LiveRoom:
             api["method"], api["url"], params, credential=self.credential
         )
 
-    async def get_room_info(self):
+    async def get_room_info(self) -> dict:
         """
         获取直播间信息（标题，简介等）
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["room_info"]
         params = {"room_id": self.room_display_id}
@@ -205,8 +219,11 @@ class LiveRoom:
         )
 
     async def get_fan_model(
-        self, page_num: int = 1, target_id: int = None, roomId: int = None
-    ):
+        self,
+        page_num: int = 1,
+        target_id: Union[int, None] = None,
+        roomId: Union[int, None] = None
+    ) -> dict:
         """
         获取自己的粉丝勋章信息
 
@@ -215,9 +232,12 @@ class LiveRoom:
         如果带有主播 id ，就返回主播的粉丝牌，没有就返回 null
 
         Args:
-            roomId(int, optional): 指定房间，查询是否拥有此房间的粉丝牌
-            target_id(int, optional): 指定返回一个主播的粉丝牌，留空就不返回
-            page_num(int, optional): 粉丝牌列表，默认 1
+            roomId    (int, optional)       : 指定房间，查询是否拥有此房间的粉丝牌
+            target_id (int | None, optional): 指定返回一个主播的粉丝牌，留空就不返回
+            page_num  (int | None, optional): 粉丝牌列表，默认 1
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
 
@@ -234,9 +254,12 @@ class LiveRoom:
             api["method"], api["url"], params=params, credential=self.credential
         )
 
-    async def get_user_info_in_room(self):
+    async def get_user_info_in_room(self) -> dict:
         """
         获取自己在直播间的信息（粉丝勋章等级，直播用户等级等）
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
 
@@ -246,12 +269,15 @@ class LiveRoom:
             api["method"], api["url"], params, credential=self.credential
         )
 
-    async def get_dahanghai(self, page: int = 1):
+    async def get_dahanghai(self, page: int = 1) -> dict:
         """
         获取大航海列表
 
         Args:
-            page (int, optional): 页码. Defaults to 1
+            page (int, optional): 页码. Defaults to 1.
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["dahanghai"]
         params = {
@@ -264,12 +290,15 @@ class LiveRoom:
             api["method"], api["url"], params, credential=self.credential
         )
 
-    async def get_gaonengbang(self, page: int = 1):
+    async def get_gaonengbang(self, page: int = 1) -> dict:
         """
         获取高能榜列表
 
         Args:
             page (int, optional): 页码. Defaults to 1
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["gaonengbang"]
         params = {
@@ -282,9 +311,12 @@ class LiveRoom:
             api["method"], api["url"], params, credential=self.credential
         )
 
-    async def get_seven_rank(self):
+    async def get_seven_rank(self) -> dict:
         """
         获取七日榜
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["seven_rank"]
         params = {
@@ -295,9 +327,12 @@ class LiveRoom:
             api["method"], api["url"], params, credential=self.credential
         )
 
-    async def get_fans_medal_rank(self):
+    async def get_fans_medal_rank(self) -> dict:
         """
         获取粉丝勋章排行
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["fans_medal_rank"]
         params = {"roomid": self.room_display_id, "ruid": await self.__get_ruid()}
@@ -305,12 +340,12 @@ class LiveRoom:
             api["method"], api["url"], params, credential=self.credential
         )
 
-    async def get_black_list(self):
+    async def get_black_list(self) -> dict:
         """
         获取黑名单列表
 
-        Args:
-            page (int, optional): 页码. Defaults to 1
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["black_list"]
         params = {"room_id": self.room_display_id, "ps": 1}
@@ -321,12 +356,15 @@ class LiveRoom:
 
     async def get_room_play_url(
         self, screen_resolution: ScreenResolution = ScreenResolution.ORIGINAL
-    ):
+    ) -> dict:
         """
         获取房间直播流列表
 
         Args:
             screen_resolution (ScreenResolution, optional): 清晰度. Defaults to ScreenResolution.ORIGINAL
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["room_play_url"]
         params = {
@@ -346,7 +384,7 @@ class LiveRoom:
         live_format: LiveFormat = LiveFormat.DEFAULT,
         live_codec: LiveCodec = LiveCodec.DEFAULT,
         live_qn: ScreenResolution = ScreenResolution.ORIGINAL,
-    ):
+    ) -> dict:
         """
         获取房间信息及可用清晰度列表
 
@@ -355,6 +393,9 @@ class LiveRoom:
             live_format   (LiveFormat, optional)      : 直播源容器格式. Defaults to LiveFormat.DEFAULT.
             live_codec    (LiveCodec, optional)       : 直播源视频编码. Defaults to LiveCodec.DEFAULT.
             live_qn       (ScreenResolution, optional): 直播源清晰度. Defaults to ScreenResolution.ORIGINAL.
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api = API["info"]["room_play_info_v2"]
         params = {
@@ -370,12 +411,15 @@ class LiveRoom:
             api["method"], api["url"], params=params, credential=self.credential
         )
 
-    async def ban_user(self, uid: int):
+    async def ban_user(self, uid: int) -> dict:
         """
         封禁用户
 
         Args:
             uid (int): 用户 UID
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
 
@@ -390,12 +434,15 @@ class LiveRoom:
             api["method"], api["url"], data=data, credential=self.credential
         )
 
-    async def unban_user(self, block_id: int):
+    async def unban_user(self, block_id: int) -> dict:
         """
         解封用户
 
         Args:
             block_id (int): 封禁用户时会返回该封禁事件的 ID，使用该值
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
         api = API["operate"]["del_block"]
@@ -408,12 +455,15 @@ class LiveRoom:
             api["method"], api["url"], data=data, credential=self.credential
         )
 
-    async def send_danmaku(self, danmaku: Danmaku):
+    async def send_danmaku(self, danmaku: Danmaku) -> dict:
         """
         直播间发送弹幕
 
         Args:
             danmaku (Danmaku): 弹幕类
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
 
@@ -429,17 +479,20 @@ class LiveRoom:
             "color": int(danmaku.color, 16),
             "fontsize": danmaku.font_size,
         }
-        print(data)
+
         return await request(
             api["method"], api["url"], data=data, credential=self.credential
         )
 
-    async def sign_up_dahanghai(self, task_id: int = 1447):
+    async def sign_up_dahanghai(self, task_id: int = 1447) -> dict:
         """
         大航海签到
 
         Args:
             task_id (int, optional): 签到任务 ID. Defaults to 1447
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
@@ -461,7 +514,7 @@ class LiveRoom:
         gift_num: int,
         storm_beat_id: int = 0,
         price: int = 0,
-    ):
+    ) -> dict:
         """
         赠送包裹中的礼物，获取包裹信息可以使用 get_self_bag 方法
 
@@ -472,6 +525,9 @@ class LiveRoom:
             gift_num (int)                  : 礼物数量
             storm_beat_id (int, optional)   : 未知， Defaults to 0
             price (int, optional)           : 礼物单价，Defaults to 0
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
@@ -494,12 +550,15 @@ class LiveRoom:
             api["method"], api["url"], data=data, credential=self.credential
         )
 
-    async def receive_reward(self, receive_type: int = 2):
+    async def receive_reward(self, receive_type: int = 2) -> dict:
         """
         领取自己在某个直播间的航海日志奖励
 
         Args:
-            receive_type (int) : 领取类型，Defaults to 2
+            receive_type (int) : 领取类型，Defaults to 2.
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
 
@@ -512,12 +571,15 @@ class LiveRoom:
             api["method"], api["url"], data=data, credential=self.credential
         )
 
-    async def get_general_info(self, act_id: int = 100061):
+    async def get_general_info(self, act_id: int = 100061) -> dict:
         """
         获取自己在该房间的大航海信息, 比如是否开通, 等级等
 
         Args:
             act_id (int, optional) : 未知，Defaults to 100061
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
 
@@ -531,9 +593,12 @@ class LiveRoom:
             api["method"], api["url"], params=params, credential=self.credential
         )
 
-    async def get_gift_common(self):
+    async def get_gift_common(self) -> dict:
         """
         获取当前直播间内的普通礼物列表
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api_room_info = API["info"]["room_info"]
         params_room_info = {
@@ -562,12 +627,15 @@ class LiveRoom:
             api["method"], api["url"], params=params, credential=self.credential
         )
 
-    async def get_gift_special(self, tab_id: int):
+    async def get_gift_special(self, tab_id: int) -> dict:
         """
         获取当前直播间内的特殊礼物列表
 
         Args:
             tab_id (int) : 2：特权礼物，3：定制礼物
+
+        Returns:
+            dict: 调用 API 返回的结果
         """
         api_room_info = API["info"]["room_info"]
         params_room_info = {
@@ -601,7 +669,7 @@ class LiveRoom:
 
     async def send_gift_gold(
         self, uid: int, gift_id: int, gift_num: int, price: int, storm_beat_id: int = 0
-    ):
+    ) -> dict:
 
         """
         赠送金瓜子礼物
@@ -613,6 +681,8 @@ class LiveRoom:
             price         (int)          : 礼物单价
             storm_beat_id (int, Optional): 未知，Defaults to 0
 
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
@@ -645,7 +715,7 @@ class LiveRoom:
         gift_num: int,
         price: int,
         storm_beat_id: int = 0,
-    ):
+    ) -> dict:
 
         """
         赠送银瓜子礼物
@@ -657,6 +727,8 @@ class LiveRoom:
             price         (int)          : 礼物单价
             storm_beat_id (int, Optional): 未知, Defaults to 0
 
+        Returns:
+            dict: 调用 API 返回的结果
         """
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
@@ -735,17 +807,17 @@ class LiveDanmaku(AsyncEvent):
         self,
         room_display_id: int,
         debug: bool = False,
-        credential: Credential = None,
+        credential: Union[Credential, None] = None,
         max_retry: int = 5,
         retry_after: float = 1,
     ):
         """
         Args:
-            room_display_id (int)                 : 房间展示 ID
-            debug           (bool, optional)      : 调试模式，将输出更多信息。. Defaults to False.
-            credential      (Credential, optional): 凭据. Defaults to None.
-            max_retry       (int, optional)       : 连接出错后最大重试次数. Defaults to 5
-            retry_after     (int, optional)       : 连接出错后重试间隔时间（秒）. Defaults to 1
+            room_display_id (int)                        : 房间展示 ID
+            debug           (bool, optional)             : 调试模式，将输出更多信息。. Defaults to False.
+            credential      (Credential | None, optional): 凭据. Defaults to None.
+            max_retry       (int, optional)              : 连接出错后最大重试次数. Defaults to 5
+            retry_after     (int, optional)              : 连接出错后重试间隔时间（秒）. Defaults to 1
         """
         super().__init__()
 
@@ -758,7 +830,7 @@ class LiveDanmaku(AsyncEvent):
         self.__ws = None
         self.__tasks = []
         self.__debug = debug
-        self.__heartbeat_timer = 30.0
+        self.__heartbeat_timer = 60.0
         self.err_reason = ""
 
         # logging
@@ -775,7 +847,7 @@ class LiveDanmaku(AsyncEvent):
             )
             self.logger.addHandler(handler)
 
-    def get_status(self):
+    def get_status(self) -> int:
         """
         获取连接状态
 
@@ -784,7 +856,7 @@ class LiveDanmaku(AsyncEvent):
         """
         return self.__status
 
-    async def connect(self):
+    async def connect(self) -> None:
         """
         连接直播间
         """
@@ -799,7 +871,7 @@ class LiveDanmaku(AsyncEvent):
 
         await self.__main()
 
-    async def disconnect(self):
+    async def disconnect(self) -> None:
         """
         断开连接
         """
@@ -814,15 +886,15 @@ class LiveDanmaku(AsyncEvent):
             self.__tasks.pop().cancel()
 
         self.__status = self.STATUS_CLOSED
-        await self.__ws.close()
+        await self.__ws.close() # type: ignore
 
         self.logger.info("连接已关闭")
 
-    async def __main(self):
+    async def __main(self) -> None:
         """
         入口
         """
-        self.__status == self.STATUS_CONNECTING
+        self.__status = self.STATUS_CONNECTING
 
         room = LiveRoom(self.room_display_id, self.credential)
         self.logger.info(f"准备连接直播间 {self.room_display_id}")
@@ -847,7 +919,7 @@ class LiveDanmaku(AsyncEvent):
         async def on_timeout(ev):
             # 连接超时
             self.err_reason = "心跳响应超时"
-            await self.__ws.close()
+            await self.__ws.close() # type: ignore
 
         while True:
             self.err_reason = ""
@@ -864,7 +936,7 @@ class LiveDanmaku(AsyncEvent):
             port = host["wss_port"]
             protocol = "wss"
             uri = f"{protocol}://{host['host']}:{port}/sub"
-            self.__status == self.STATUS_CONNECTING
+            self.__status = self.STATUS_CONNECTING
             self.logger.info(f"正在尝试连接主机： {uri}")
 
             try:
@@ -899,14 +971,14 @@ class LiveDanmaku(AsyncEvent):
                 # 正常断开情况下跳出循环
                 if self.__status != self.STATUS_CLOSED or self.err_reason:
                     # 非用户手动调用关闭，触发重连
-                    raise LiveException(
+                    self.logger.warning(
                         "非正常关闭连接" if not self.err_reason else self.err_reason
                     )
                 else:
                     break
 
             except Exception as e:
-                self.logger.exception(e)
+                self.logger.warning(e)
                 if retry <= 0 or len(available_hosts) == 0:
                     self.logger.error("无法连接服务器")
                     self.err_reason = "无法连接服务器"
@@ -917,7 +989,7 @@ class LiveDanmaku(AsyncEvent):
                 retry -= 1
                 await asyncio.sleep(self.retry_after)
 
-    async def __handle_data(self, data):
+    async def __handle_data(self, data) -> None:
         """
         处理数据
         """
@@ -970,7 +1042,7 @@ class LiveDanmaku(AsyncEvent):
             else:
                 self.logger.warning("检测到未知的数据包类型，无法处理")
 
-    async def __send_verify_data(self, ws: ClientWebSocketResponse, token: str):
+    async def __send_verify_data(self, ws: ClientWebSocketResponse, token: str) -> None:
         verifyData = {
             "uid": 0,
             "roomid": self.__room_real_id,
@@ -984,7 +1056,7 @@ class LiveDanmaku(AsyncEvent):
             data, self.PROTOCOL_VERSION_HEARTBEAT, self.DATAPACK_TYPE_VERIFY, ws
         )
 
-    async def __heartbeat(self, ws: ClientWebSocketResponse):
+    async def __heartbeat(self, ws: ClientWebSocketResponse) -> None:
         """
         定时发送心跳包
         """
@@ -997,6 +1069,17 @@ class LiveDanmaku(AsyncEvent):
             if self.__heartbeat_timer == 0:
                 self.logger.debug("发送心跳包")
                 await ws.send_bytes(HEARTBEAT)
+                heartbeat_url = "https://live-trace.bilibili.com/xlive/rdata-interface/v1/heartbeat/webHeartBeat?pf=web&hb="
+                hb = str(base64.b64encode(f"60|{self.room_display_id}|1|0".encode("utf-8")), "utf-8")
+                await request(
+                    "GET",
+                    heartbeat_url,
+                    params = {
+                        "hb": hb,
+                        "pf": "web"
+                    },
+                    json_body = True
+                )
             elif self.__heartbeat_timer <= -30:
                 # 视为已异常断开连接，发布 TIMEOUT 事件
                 self.dispatch("TIMEOUT")
@@ -1011,7 +1094,7 @@ class LiveDanmaku(AsyncEvent):
         protocol_version: int,
         datapack_type: int,
         ws: ClientWebSocketResponse,
-    ):
+    ) -> None:
         """
         自动打包并发送数据
         """
@@ -1020,7 +1103,7 @@ class LiveDanmaku(AsyncEvent):
         await ws.send_bytes(data)
 
     @staticmethod
-    def __pack(data: bytes, protocol_version: int, datapack_type: int):
+    def __pack(data: bytes, protocol_version: int, datapack_type: int) -> bytes:
         """
         打包数据
         """
@@ -1036,7 +1119,7 @@ class LiveDanmaku(AsyncEvent):
         return bytes(sendData)
 
     @staticmethod
-    def __unpack(data: bytes):
+    def __unpack(data: bytes) -> List[Any]:
         """
         解包数据
         """
@@ -1085,9 +1168,12 @@ class LiveDanmaku(AsyncEvent):
         return ret
 
 
-async def get_self_info(credential: Credential):
+async def get_self_info(credential: Credential) -> dict:
     """
     获取自己直播等级、排行等信息
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
     credential.raise_for_no_sessdata()
 
@@ -1095,9 +1181,12 @@ async def get_self_info(credential: Credential):
     return await request(api["method"], api["url"], credential=credential)
 
 
-async def get_self_live_info(credential: Credential):
+async def get_self_live_info(credential: Credential) -> dict:
     """
     获取自己的粉丝牌、大航海等信息
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
 
     credential.raise_for_no_sessdata()
@@ -1107,8 +1196,10 @@ async def get_self_live_info(credential: Credential):
 
 
 async def get_self_dahanghai_info(
-    page: int = 1, page_size: int = 10, credential: Credential = None
-):
+    page: int = 1,
+    page_size: int = 10,
+    credential: Union[Credential, None] = None
+) -> dict:
     """
     获取自己开通的大航海信息
 
@@ -1124,6 +1215,9 @@ async def get_self_dahanghai_info(
     info = live.get_self_live_info(credential)
     pages = math.ceil(info['data']['guards'] / 10)
     ```
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
     if credential is None:
         credential = Credential()
@@ -1137,9 +1231,12 @@ async def get_self_dahanghai_info(
     )
 
 
-async def get_self_bag(credential: Credential):
+async def get_self_bag(credential: Credential) -> dict:
     """
     获取自己的直播礼物包裹信息
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
 
     credential.raise_for_no_sessdata()
@@ -1149,7 +1246,9 @@ async def get_self_bag(credential: Credential):
 
 
 async def get_gift_config(
-    room_id: int = None, area_id: int = None, area_parent_id: int = None
+    room_id: Union[int, None] = None,
+    area_id: Union[int, None] = None,
+    area_parent_id: Union[int, None] = None
 ):
     """
     获取所有礼物的信息，包括礼物 id、名称、价格、等级等。
@@ -1160,6 +1259,9 @@ async def get_gift_config(
         room_id (int, optional)         : 房间显示 ID. Defaults to None.
         area_id (int, optional)         : 子分区 ID. Defaults to None.
         area_parent_id (int, optional)  : 父分区 ID. Defaults to None.
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
     api = API["info"]["gift_config"]
     params = {
@@ -1172,22 +1274,29 @@ async def get_gift_config(
     return await request(api["method"], api["url"], params=params)
 
 
-async def get_area_info():
+async def get_area_info() -> dict:
     """
     获取所有分区信息
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
     api = API["info"]["area_info"]
     return await request(api["method"], api["url"])
 
 
 async def get_live_followers_info(
-    need_recommend: bool = True, credential: Credential = None
-):
+    need_recommend: bool = True,
+    credential: Union[Credential, None] = None
+) -> dict:
     """
     获取关注列表中正在直播的直播间信息，包括房间直播热度，房间名称及标题，清晰度，是否官方认证等信息。
 
     Args:
         need_recommend (bool, optional): 是否接受推荐直播间，Defaults to True
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
     if credential is None:
         credential = Credential()
@@ -1202,14 +1311,19 @@ async def get_live_followers_info(
 
 
 async def get_unlive_followers_info(
-    page: int = 1, page_size: int = 30, credential: Credential = None
-):
+    page: int = 1,
+    page_size: int = 30,
+    credential: Union[Credential, None] = None
+) -> dict:
     """
     获取关注列表中未在直播的直播间信息，包括上次开播时间，上次开播的类别，直播间公告，是否有录播等。
 
     Args:
         page      (int, optional): 页码, Defaults to 1.
         page_size (int, optional): 每页数量 Defaults to 30.
+
+    Returns:
+        dict: 调用 API 返回的结果
     """
     if credential is None:
         credential = Credential()
