@@ -8,6 +8,7 @@ from html import unescape
 import json
 from enum import Enum
 
+from yarl import URL
 from .utils.utils import get_api
 from .utils.Credential import Credential
 from .utils.network_httpx import request, get_session
@@ -346,8 +347,8 @@ class Note:
         for node in self.__children:
             try:
                 markdown_text = node.markdown()
-            except:
-                continue
+            except Exception as e:
+                pass
             else:
                 content += markdown_text
 
@@ -368,7 +369,7 @@ class Note:
             raise ApiException("请先调用 fetch_content()")
 
         return {
-            "type": "Article",
+            "type": "Note",
             "meta": self.__meta,
             "children": list(map(lambda x: x.json(), self.__children)),
         }
@@ -599,10 +600,14 @@ class ImageNode(Node):
         self.alt = ""
 
     def markdown(self):
+        if URL(self.url).scheme == "":
+            self.url = "https:" + self.url
         alt = self.alt.replace("[", "\\[")
         return f"![{alt}]({self.url})\n\n"
 
     def json(self):
+        if URL(self.url).scheme == "":
+            self.url = "https:" + self.url
         return {"type": "ImageNode", "url": self.url, "alt": self.alt}
 
 
