@@ -23,6 +23,7 @@ from ..favorite_list import FavoriteList, FavoriteListType
 from ..interactive_video import InteractiveVideo
 from ..live import LiveRoom
 from ..user import ChannelSeries, ChannelSeriesType, User, get_self_info
+from ..note import Note, NoteType
 from ..video import Video
 from ..game import Game
 from .Credential import Credential
@@ -31,7 +32,7 @@ from .utils import get_api
 from ..topic import Topic
 from ..manga import Manga
 from ..album import Album
-
+from .initial_state import get_initial_state
 
 class ResourceType(Enum):
     """
@@ -54,6 +55,7 @@ class ResourceType(Enum):
     + TOPIC: 话题
     + MANGA: 漫画
     + ALBUM: 相簿
+    + NOTE: 笔记
     + FAILED: 错误
     """
 
@@ -76,6 +78,7 @@ class ResourceType(Enum):
     TOPIC = "topic"
     MANGA = "manga"
     ALBUM = "album"
+    NOTE = "note"
     FAILED = "failed"
 
 
@@ -102,6 +105,7 @@ async def parse_link(
     Tuple[Topic, Literal[ResourceType.TOPIC]],
     Tuple[Manga, Literal[ResourceType.MANGA]],
     Tuple[Album, Literal[ResourceType.ALBUM]],
+    Tuple[Note, Literal[ResourceType.NOTE]],
     Tuple[Literal[-1], Literal[ResourceType.FAILED]]
 ]:
     """
@@ -115,6 +119,7 @@ async def parse_link(
         Tuple[obj, ResourceType]: (对象，类型) 或 -1,-1 表示出错
     """
     credential = credential if credential else Credential()
+    url = url.replace("\\", "/") # 说多了都是泪
     try:
         obj = None
 
@@ -152,7 +157,8 @@ async def parse_link(
         if channel != -1:
             return (channel, ResourceType.CHANNEL_SERIES) # type: ignore
 
-        url = await get_real_url(url) # type: ignore
+        url = await get_real_url(str(url)) # type: ignore
+        url = URL(url) # type: ignore
 
         fl_space = parse_space_favorite_list(url, credential) # type: ignore
         if fl_space != -1:
@@ -169,6 +175,10 @@ async def parse_link(
         if bnj_video != -1:
             bnj_video.credential = credential # type: ignore
             return (bnj_video, ResourceType.VIDEO) # type: ignore
+        note = parse_note(url, credential) # type: ignore
+        if note != -1:
+            return (note, ResourceType.NOTE) # type: ignore
+
 
         obj = None
         video = await parse_video(url, credential) # type: ignore
@@ -177,7 +187,7 @@ async def parse_link(
         bangumi = parse_bangumi(url, credential) # type: ignore
         if not bangumi == -1:
             obj = (bangumi, ResourceType.BANGUMI)
-        episode = parse_episode(url, credential) # type: ignore
+        episode = await parse_episode(url, credential) # type: ignore
         if not episode == -1:
             obj = (episode, ResourceType.EPISODE)
         favorite_list = parse_favorite_list(url, credential) # type: ignore
@@ -316,7 +326,7 @@ def parse_bangumi(url: URL, credential: Credential) -> Union[Bangumi, int]:
     return -1
 
 
-def parse_episode(url: URL, credential: Credential) -> Union[Episode, int]:
+async def parse_episode(url: URL, credential: Credential) -> Union[Episode, int]:
     """
     解析番剧剧集,如果不是返回 -1，否则返回对应类
     """
@@ -328,28 +338,9 @@ def parse_episode(url: URL, credential: Credential) -> Union[Episode, int]:
                 epid = int(video_short_id[2:])
                 return Episode(epid=epid)
             elif video_short_id[:2].upper() == "SS":
-                try:
-                    resp = httpx.get(
-                        str(url),
-                        cookies=credential.get_cookies(),
-                        headers={"User-Agent": "Mozilla/5.0"},
-                    )
-                except Exception as e:
-                    raise ResponseException(str(e))
-                else:
-                    content = resp.text
-
-                    pattern = re.compile(r"window.__INITIAL_STATE__=(\{.*?\});")
-                    match = re.search(pattern, content)
-                    if match is None:
-                        raise ApiException("未找到番剧信息")
-                    try:
-                        content = json.loads(match.group(1))
-                    except json.JSONDecodeError:
-                        raise ApiException("信息解析错误")
-                    else:
-                        epid = content["epInfo"]["id"]
-                        return Episode(epid=epid, credential=credential)
+                content = await get_initial_state(str(url), credential=credential)
+                epid = content["epInfo"]["id"]
+                return Episode(epid=epid, credential=credential)
     return -1
 
 
@@ -592,3 +583,12 @@ def parse_bnj(url: URL, credential: Credential) -> Union[Video, int]:
     if bvid is not None:
         return Video(bvid, credential=credential)
     return -1
+
+
+def parse_note(url: URL, credential: Credential) -> Union[Note, int]:
+    # https://www.bilibili.com/h5/note-app/view?cvid=21385583
+    if url.host == "www.bilibili.com" and url.parts[1:4] == ("h5", "note-app", "view"):
+        if url.query.get("cvid") == None:
+            return -1
+        return Note(cvid=int(url.query.get("cvid")), note_type=NoteType.PUBLIC, credential=credential) # type: ignore
+    return -1
