@@ -29,34 +29,283 @@ from .utils.network import get_session as get_session_aiohttp
 from .utils.Danmaku import Danmaku, SpecialDanmaku
 from .utils.BytesReader import BytesReader
 from .utils.AsyncEvent import AsyncEvent
+from dataclasses import dataclass
 from . import settings
 
 API = get_api("video")
 
-# 视频分辨率
-VIDEO_QUALITY = {
-    126: "杜比视界",
-    125: "真彩 HDR",
-    120: "超清 4K",
-    116: "高清 1080P60",
-    112: "高清 1080P+",
-    80: "高清 1080P",
-    64: "高清 720P60",
-    32: "清晰 480P",
-    16: "流畅 360P",
-}
 
-# 视频编码 | if "hev" in codecs: HEVC(H.265) |
-VIDEO_CODECS = {"hev": "HEVC(H.265)", "avc": "AVC(H.264)", "av01": "AV1"}
+class VideoQuality(Enum):
+    """
+    视频的视频流分辨率枚举
 
-# 音频编码
-AUDIO_QUALITY = {
-    30216: "64 K",
-    30232: "132 K",
-    30250: "杜比全景声",
-    30251: "Hi-Res 无损",
-    30280: "192 K",
-}
+    - _360P: 流畅 360P
+    - _480P: 清晰 480P
+    - _720P: 高清 720P60
+    - _1080P: 高清 1080P
+    - _1080P_PLUS: 高清 1080P 高码率
+    - _1080P_60: 高清 1080P 60 帧码率
+    - _4K: 超清 4K
+    - HDR: 真彩 HDR
+    - DOLBY: 杜比视界
+    - _8K: 超高清 8K
+    """
+    _360P = 16
+    _480P = 32
+    _720P = 64
+    _1080P = 80
+    _1080P_PLUS = 112
+    _1080P_60 = 116
+    _4K = 120
+    HDR = 125
+    DOLBY = 126
+    _8K = 127
+
+
+
+class VideoCodecs(Enum):
+    """
+    视频的视频流编码枚举
+
+    - HEV: HEVC(H.265)
+    - AVC: AVC(H.264)
+    - AV1: AV1
+    """
+    HEV = "hev"
+    AVC = "avc"
+    AV1 = "av01"
+
+
+class AudioQuality(Enum):
+    """
+    视频的音频流清晰度枚举
+
+    - _64K: 64K
+    - _132K: 132K
+    - _192K: 192K
+    - HI_RES: Hi-Res 无损
+    - DOLBY: 杜比全景声
+    """
+    _64K = 30216
+    _132K = 30232
+    DOLBY = 30250
+    HI_RES = 30251
+    _192K = 30280
+
+
+@dataclass
+class VideoStreamDownloadURL:
+    """
+    (@dataclass)
+
+    视频流 URL 类
+
+    Attributes:
+        url           (str)         : 视频流 url
+        video_quality (VideoQuality): 视频流清晰度
+        video_codecs  (VideoCodecs) : 视频流编码
+    """
+    url: str
+    video_quality: VideoQuality
+    video_codecs: VideoCodecs
+
+
+@dataclass
+class AudioStreamDownloadURL:
+    """
+    (@dataclass)
+
+    音频流 URL 类
+
+    Attributes:
+        url           (str)         : 音频流 url
+        audio_quality (AudioQuality): 音频流清晰度
+    """
+    url: str
+    audio_quality: AudioQuality
+
+
+@dataclass
+class FLVStreamDownloadURL:
+    """
+    (@dataclass)
+
+    FLV 视频流
+
+    Attributes:
+        url           (str): FLV 流 url
+    """
+    url: str
+
+
+@dataclass
+class HTML5MP4DownloadURL:
+    """
+    (@dataclass)
+
+    可供 HTML5 播放的 mp4 视频流
+
+    Attributes:
+        url           (str): HTML5 mp4 视频流
+    """
+    url: str
+
+
+
+class VideoDownloadURLDataDetecter:
+    """
+    `Video.get_download_url` 返回结果解析类。
+
+    在调用 `Video.get_download_url` 之后可以将代入 `VideoDownloadURLDataDetecter`，此类将一键解析。
+
+    目前支持:
+      - 视频清晰度: 360P, 480P, 720P, 1080P, 1080P 高码率, 1080P 60 帧, 4K, HDR, 杜比视界, 8K
+      - 视频编码: HEVC(H.265), AVC(H.264), AV1
+      - 音频清晰度: 64K, 132K, Hi-Res 无损音效, 杜比全景声, 192K
+      - FLV 视频流
+    """
+    def __init__(self, data: dict):
+        """
+        Args:
+            data (dict): `Video.get_download_url` 返回的结果
+        """
+        self.__data = data
+
+    def check_video_and_audio_stream(self) -> bool:
+        """
+        判断是否为音视频分离流
+
+        Returns:
+            bool: 是否为音视频分离流
+        """
+        if "dash" in self.__data.keys():
+            return True
+        return False
+
+    def check_flv_stream(self) -> bool:
+        """
+        判断是否为 FLV 视频流
+
+        Returns:
+            bool: 是否为 FLV 视频流
+        """
+        if "durl" in self.__data.keys():
+            if self.__data["format"].startswith("flv"):
+                return True
+        return False
+
+    def check_html5_mp4_stream(self) -> bool:
+        """
+        判断是否为 HTML5 可播放的 mp4 视频流
+
+        Returns:
+            bool: 是否为 HTML5 可播放的 mp4 视频流
+        """
+        if "durl" in self.__data.keys():
+            if self.__data["format"].startswith("mp4"):
+                return True
+        return False
+
+    def detect_all(self) -> \
+        List[
+            Union[
+                VideoStreamDownloadURL,
+                AudioStreamDownloadURL,
+                FLVStreamDownloadURL,
+                HTML5MP4DownloadURL
+            ]
+        ]:
+        """
+        解析数据
+
+        Returns:
+            List[VideoStreamDownloadURL | AudioStreamDownloadURL | FLVStreamDownloadURL | HTML5MP4DownloadURL]: 所有的视频/音频流
+        """
+        if "durl" in self.__data.keys():
+            if self.__data["format"].startswith("flv"):
+                # FLV 视频流
+                return [FLVStreamDownloadURL(url = self.__data["durl"][0]["url"])]
+            else:
+                # HTML5 MP4 视频流
+                return [HTML5MP4DownloadURL(url = self.__data["durl"][0]["url"])]
+        else:
+            # 正常情况
+            streams = []
+            videos_data = self.__data["dash"]["video"]
+            audios_data = self.__data["dash"]["audio"]
+            flac_data = self.__data["dash"]["flac"]
+            dolby_data = self.__data["dash"]["dolby"]
+            for video_data in videos_data:
+                video_stream_url = video_data["baseUrl"]
+                video_stream_quality = VideoQuality(video_data["id"])
+                video_stream_codecs = None
+                for val in VideoCodecs:
+                    if val.value in video_data["codecs"]:
+                        video_stream_codecs = val
+                video_stream = VideoStreamDownloadURL(
+                    url=video_stream_url,
+                    video_quality=video_stream_quality,
+                    video_codecs=video_stream_codecs # type: ignore
+                )
+                streams.append(video_stream)
+            for audio_data in audios_data:
+                audio_stream_url = audio_data["baseUrl"]
+                audio_stream_quality = AudioQuality(audio_data["id"])
+                audio_stream = AudioStreamDownloadURL(
+                    url=audio_stream_url,
+                    audio_quality=audio_stream_quality
+                )
+                streams.append(audio_stream)
+            if flac_data:
+                if flac_data["audio"]:
+                    for flac in flac_data["audio"]:
+                        flac_stream_url = flac["baseUrl"]
+                        flac_stream_quality = AudioQuality(flac["id"])
+                        flac_stream = AudioStreamDownloadURL(
+                            url=flac_stream_url,
+                            audio_quality=flac_stream_quality
+                        )
+                        streams.append(flac_stream)
+            if dolby_data:
+                if dolby_data["audio"]:
+                    for dolby in dolby_data["audio"]:
+                        dolby_stream_url = dolby["baseUrl"]
+                        dolby_stream_quality = AudioQuality(dolby["id"])
+                        dolby_stream = AudioStreamDownloadURL(
+                            url=dolby_stream_url,
+                            audio_quality=dolby_stream_quality
+                        )
+                        streams.append(dolby_stream)
+            return streams
+
+    def detect_best_streams(self) -> \
+        Union[
+            List[FLVStreamDownloadURL],
+            List[HTML5MP4DownloadURL],
+            List[Union[VideoStreamDownloadURL, AudioStreamDownloadURL]]
+        ]:
+        """
+        提取出分辨率、音质等信息最好的音视频流
+
+        Returns:
+            List[VideoStreamDownloadURL | AudioStreamDownloadURL | FLVStreamDownloadURL | HTML5MP4DownloadURL]: FLV 视频流 / HTML5 MP4 视频流返回 `[FLVStreamDownloadURL | HTML5MP4StreamDownloadURL]`, 否则为 `[VideoStreamDownloadURL, AudioStreamDownloadURL]`
+        """
+        if self.check_flv_stream():
+            return self.detect_all() # type: ignore
+        elif self.check_html5_mp4_stream():
+            return self.detect_all() # type: ignore
+        else:
+            data = self.detect_all()
+            video_streams = []
+            audio_streams = []
+            for stream in data:
+                if isinstance(stream, VideoStreamDownloadURL):
+                    video_streams.append(stream)
+                if isinstance(stream, AudioStreamDownloadURL):
+                    audio_streams.append(stream)
+            video_streams.sort(key=lambda s: s.video_quality.value, reverse=True)
+            audio_streams.sort(key=lambda s: s.audio_quality.value, reverse=True)
+            return [video_streams[0], audio_streams[0]]
 
 
 class DanmakuOperatorType(Enum):
@@ -179,15 +428,21 @@ class Video:
         params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
         return await request("GET", url, params=params, credential=self.credential)
 
-    async def get_tags(self) -> dict:
+    async def get_tags(self, page_index: int = 0, cid: int = None) -> dict:
         """
         获取视频标签。
 
+        Args:
+            page_index (int): 分 P 序号. Defaults to 0.
+            cid        (int): 分 P 编码. Defaults to None.
+
         Returns:
             dict: 调用 API 返回的结果。
         """
+        if cid == None:
+            cid = await self.get_cid(page_index = page_index)
         url = API["info"]["tags"]["url"]
-        params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
+        params = {"bvid": self.get_bvid(), "aid": self.get_aid(), "cid": cid}
         return await request("GET", url, params=params, credential=self.credential)
 
     async def get_chargers(self) -> dict:
@@ -287,6 +542,8 @@ class Video:
         """
         获取视频下载信息。
 
+        返回结果可以传入 `VideoDownloadURLDataDetecter` 进行解析。
+
         page_index 和 cid 至少提供其中一个，其中 cid 优先级最高
 
         Args:
@@ -379,21 +636,6 @@ class Video:
             "favoured"
         ]
 
-    async def get_media_list(self) -> dict:
-        """
-        获取收藏夹列表信息，用于收藏操作，含各收藏夹对该视频的收藏状态。
-
-        Returns:
-            dict: 调用 API 返回的结果。
-        """
-        self.credential.raise_for_no_sessdata()
-
-        info = await self.__get_info_cached()
-
-        url = API["info"]["media_list"]["url"]
-        params = {"type": 2, "rid": self.get_aid(), "up_mid": info["owner"]["mid"]}
-        return await request("GET", url, params=params, credential=self.credential)
-
     async def is_forbid_note(self) -> bool:
         """
         是否禁止笔记。
